Lua_MainLineBubbleItem = class("Lua_MainLineBubbleItem", Lua_DisplayObject)
function Lua_MainLineBubbleItem:ctor(p)
	self:superCall("ctor", p, "MainLineBubbleItem_skin");
end

function Lua_MainLineBubbleItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_MainLineBubbleItem:dispose()
	self:stopTimer();
	self.config = nil;
	self.viewRoot = nil;
	self.bubbleId = nil;
	self:superCall("dispose");
end

function Lua_MainLineBubbleItem:setData(data)
	self.config = getConfig("mainline_bubble", data);
	if self.config == nil then
		self:hide();
		return;
	end

	if self.bubbleId == data then
		return;
	end
	self.bubbleId = data;

	self:updateData();
	self:startTimer();
end

function Lua_MainLineBubbleItem:updateData()
	local modelId = DataCenter.mainLinePreViewController:getBubbleModel(self.config.model_idx);
	local modelCfg = Lua_ModelConfigData.getConfig(modelId);
	self.bubbleRoot = modelCfg.mainLineBubbleRoot;
	self:updatePos();

	self.contentTxt.text = self.config.content;
	self.contentTxt:resetSize();
	self.bg:SetDimensions(223, self.contentTxt.height + 50);

	self.dialogPlayTime = self.config.play_sec == nil and 1 or self.config.play_sec / 1000;
	self.dialogPauseTime = self.config.pause_sec == nil and 1 or self.config.pause_sec / 1000;
	if self.dialogPlayTime <= 0 then
		self.contentTxtLen = -1;
		self.playedTime = -1;
		self.pauseTime = 0;
		self.contentTxt:setTextShowIndex(-1);
		self:hide();
	else -- 开始逐字播放
		self.playedTime = 0;
		self.pauseTime = 0;
		self.contentTxtLen = self.contentTxt.showTextLen;
		self.contentTxt:setTextShowIndex(0);
	end
end

function Lua_MainLineBubbleItem:hide()
	self:stopTimer();
	self.bubbleId = nil;
	Lua_MsgUtil.callFunc("MAINLINE_BUBBLE_HIDE");
end

function Lua_MainLineBubbleItem:startTimer()
	if not self.bTimer then
		self.bTimer = true;
		self.curFrameTime = getTime();
		self.playSpeed = 1;
		self:addTimer("Lua_MainLineBubbleItem", 0.02, self, self.onTimer);
	end
end

function Lua_MainLineBubbleItem:stopTimer()
	if self.bTimer then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_MainLineBubbleItem:onTimer()
	self:updatePos();

	local t = getTime();
	local dt = (t - self.curFrameTime); -- 等比加速
	local scaleDelayTime = dt * self.playSpeed;
	self.curFrameTime = t;

	if self.pauseTime > 0 then
		self.pauseTime = self.pauseTime - scaleDelayTime;
		if self.pauseTime <= 0 then
			self.config = getConfig("mainline_bubble", self.bubbleId + 1);
			if self.config == nil then
				self:hide();
			else
				self.bubbleId = self.config.id;
				self:updateData();
			end
		end
		return;
	end

	if self.playedTime >= 0 then
		self.playedTime = self.playedTime + scaleDelayTime;
		local rate = self.playedTime / self.dialogPlayTime;
		if rate >= 1 then
			self.playedTime = -1;
			local content = self.contentTxt.text;
			self.contentTxt.text = nil;
			self.contentTxt.text = content;
			self.pauseTime = self.dialogPauseTime;
		else
			local num = Mathf.Floor(rate * self.contentTxtLen);
			self.contentTxt:setTextShowIndex(num);
		end
	end
end

function Lua_MainLineBubbleItem:updatePos()
	LuaUtil.setUIObjPos(self.parent, self.content, self.bubbleRoot, 0, 0, 0);
end