Lua_MainLineMapWindow = class("Lua_MainLineMapWindow", Lua_Window)
function Lua_MainLineMapWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_MainLineMapWindow";
	self.isFullSizeWin = true;

	self.showImgPath = "/images/main_line/map.jpg";
	self.mapWidth = 2160;
	self.mapHight = 1900;
	self:addPreLoadRes(self.showImgPath, Lua_LoadFileType.IMG);
end

function Lua_MainLineMapWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.itemList = Array();

	self.scrollContainer = UICreate.createScrollContainer(self.content, 0, 0, self.width, self.height);
	self.scrollContainer.bCreateContent = true;
	self.scrollContainer.horizontal = true;
	self.scrollContainer.vertical = true;
	self.scrollContainer.movementTypeValue = 2;
	self.scrollContainer.elasticity = 0.3;
	self.scrollContainer.inertia = true;
	self.scrollContainer:setScrollPosition(0, 0, 0);
	self.scrollContainer:setScrollSize(self.mapWidth, self.mapHight);
	self.scrollContainer:setScrollAnchor(0, 1, 0, 1);
	self.scrollContainer:setScrollPivot(0);
	self.scrollContainer:addMousDownFuntion(self, self.onMouseDownFun);
	self.scrollContainer:addMouseUpFuntion(self, self.onMouseUpFun);

	self.scrollContent = self.scrollContainer.scrollContent;
    self.scrollRect = self.scrollContainer.scrollRect;

	self.showImg = UICreate.createImage(self.scrollContent, self.showImgPath, 0, 0, self.mapWidth, self.mapHight);
	local config = getConfig("mainline_chapter");
	local item;
	for k in pairs(config) do
		item = self.itemList[i];
		if item == nil then
			item = Lua_MainLineChapterItem.new(self.scrollContent);
			item:setRectAnchor(0);
			self.itemList:add(item);
		end
		item.contentName = i;
		item:setData(k);
	end

	self:createBackBtn();
	self:updateShowInfo();
end

function Lua_MainLineMapWindow:dispose()
	self:stopTimer();
	if self.itemList then
		self.itemList:dispose();
		self.itemList:clear();
		self.itemList = nil;
	end
	self.scrollContent = nil;
	self.scrollRect = nil;
	if self.scrollContainer ~= nil then
		self.scrollContainer:dispose();
		self.scrollContainer = nil;
	end
	self:superCall("dispose");
end

function Lua_MainLineMapWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.scrollContainer:SetDimensions(self.width, self.height);
end

function Lua_MainLineMapWindow:updateShowInfo()
	self:setCamMove(0, 0, true)
end

function Lua_MainLineMapWindow:setCamMove(posX, posY, isNow)
	self:stopTimer();

	local camPosX = -(posX - self.width / 2);
	if camPosX > 0 then
		camPosX = 0;
	elseif camPosX < -(self.mapWidth - self.width) then
		camPosX = -(self.mapWidth - self.width);
	end

	local camPosY = -(posY + self.height / 2);
	if camPosY > self.mapHight - self.height then
		camPosY = self.mapHight - self.height;
	elseif camPosY < 0 then
		camPosY = 0;
	end

	self.camPosX = camPosX;
	self.camPosY = camPosY;
	if isNow then
		self.scrollContainer:setScrollPosition(camPosX, camPosY, 0);
	else
		self:starTimer();
	end
end

function Lua_MainLineMapWindow:starTimer()
	if not self.bTimer then
		self.bTimer = true;
		DataCenter.loginData:checkFpsState();
		self:addTimer("Lua_MainLineMapWindow", 0.02, self, self.onTimer);
	end
end

function Lua_MainLineMapWindow:stopTimer()
	if self.bTimer then
		self.bTimer = false;
		DataCenter.loginData:checkFpsState();
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_MainLineMapWindow:onTimer()
	local posX = self.scrollRect.anchoredPosition.x;
	local posY = self.scrollRect.anchoredPosition.y;
	local disX = self.camPosX - posX;
	local disY = self.camPosY - posY;
	if Mathf.Abs(disX) <= 2 and Mathf.Abs(disY) <= 2 then
		self:stopTimer();
		self.scrollContainer:setScrollPosition(self.camPosX, self.camPosY, 0);
	else
		self.scrollContainer:setScrollPosition(posX + disX * 0.1, posY + disY * 0.1, 0);
	end
end

function Lua_MainLineMapWindow:onMouseDownFun()
	self:stopTimer();
	self.startClickTime = getTime();
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;
end

function Lua_MainLineMapWindow:onMouseUpFun()
	local disX = CommonUtil.mousePositionX - self.startMouseX;
	local disY = CommonUtil.mousePositionY - self.startMouseY;
	if getTime() - self.startClickTime <= 0.3 and Mathf.Abs(disX) <= 2 and Mathf.Abs(disY) <= 2 then

	end
end










Lua_MainLineChapterItem = class("Lua_MainLineChapterItem", Lua_DisplayObject)
function Lua_MainLineChapterItem:ctor(p)
	self:superCall("ctor", p, "MainLineChapterItem_skin");
end

function Lua_MainLineChapterItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_MainLineChapterItem:dispose()
	self:superCall("dispose");
end

function Lua_MainLineChapterItem:setData(chapterId)
	local config = Lua_MainLineChapterConfigData.getConfig(chapterId);
	self:setLocation(config.mapPosTab[1], config.mapPosTab[2], 0);
	self.nameText.text = config.name;
end